@@ -1,7 +1,7 @@
 package PERLANCAR::AppUtil::PerlStripper;
 
 our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,11 +28,6 @@ sub _add_stripper_args_to_meta {
         schema => ['bool'],
         default => 0,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     $meta->{args}{stripper_ws} = {
@@ -41,11 +36,6 @@ _
         schema => ['bool'],
         default => 1,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     $meta->{args}{stripper_comment} = {
@@ -53,11 +43,6 @@ _
         'summary.alt.bool.not' => "Set strip_comment=0 (don't strip comments) in Perl::Stripper",
         schema => ['bool'],
         default => 1,
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
         tags => ['category:stripping'],
     };
 
@@ -67,11 +52,6 @@ _
         schema => ['bool'],
         default => 1,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     $meta->{args}{stripper_log} = {
@@ -80,11 +60,6 @@ _
         schema => ['bool'],
         default => 0,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     # XXX strip_log_levels
@@ -128,7 +103,7 @@ PERLANCAR::AppUtil::PerlStripper - Utilities for PERLANCAR's applications, relat
 
 =head1 VERSION
 
-This document describes version 0.02 of PERLANCAR::AppUtil::PerlStripper (from Perl distribution PERLANCAR-AppUtil-PerlStripper), released on 2015-06-17.
+This document describes version 0.03 of PERLANCAR::AppUtil::PerlStripper (from Perl distribution PERLANCAR-AppUtil-PerlStripper), released on 2015-06-17.
 
 =for Pod::Coverage .+
 
